==> imp-doc-2.1.1.tar.gz: html/allmod.js <==
var allmod =
[
    [ "IMP.algebra", "impalgebra.html", [
      [ "Geometric primitives", "impalgebra.html#geometricprimitives", null ],
      [ "Generic geometry", "impalgebra.html#genericgeometry", null ],
      [ "ANN", "impalgebra.html#ANN", null ]
    ] ],
    [ "IMP.atom", "impatom.html", null ],
    [ "IMP.base", "impbase.html", [
      [ "Graphs", "impbase.html#graphs", null ],
      [ "Values and Objects (C++ only)", "impbase.html#values", null ],
      [ "Google Perf Tools", "impbase.html#perf", null ]
    ] ],
    [ "IMP.benchmark", "impbenchmark.html", null ],
    [ "IMP.cgal", "impcgal.html", [
      [ "CGAL", "impcgal.html#CGAL", null ]
    ] ],
    [ "IMP.cnmultifit", "impcnmultifit.html", null ],
    [ "IMP.container", "impcontainer.html", null ],
    [ "IMP.core", "impcore.html", null ],
    [ "IMP.display", "impdisplay.html", null ],
    [ "IMP.domino", "impdomino.html", null ],
    [ "IMP.em", "impem.html", null ],
    [ "IMP.em2d", "impem2d.html", [
      [ "OpenCV", "impem2d.html#OpenCV", null ]
    ] ],
    [ "IMP.example", "impexample.html", null ],
    [ "IMP.gsl", "impgsl.html", [
      [ "GSL", "impgsl.html#GSL", null ]
    ] ],
    [ "IMP.isd", "impisd.html", null ],
    [ "IMP.kernel", "impkernel.html", null ],
    [ "IMP.kinematics", "impkinematics.html", null ],
    [ "IMP.kmeans", "impkmeans.html", null ],
    [ "IMP.misc", "impmisc.html", null ],
    [ "IMP.modeller", "impmodeller.html", [
      [ "Modeller", "impmodeller.html#modeller", null ]
    ] ],
    [ "IMP.mpi", "impmpi.html", null ],
    [ "IMP.multifit", "impmultifit.html", null ],
    [ "IMP.parallel", "impparallel.html", null ],
    [ "IMP.pepdock", "imppepdock.html", null ],
    [ "IMP.restrainer", "imprestrainer.html", null ],
    [ "IMP.rmf", "imprmf.html", null ],
    [ "IMP.rotamer", "improtamer.html", null ],
    [ "IMP.saxs", "impsaxs.html", null ],
    [ "IMP.score_functor", "impscore_functor.html", null ],
    [ "IMP.scratch", "impscratch.html", null ],
    [ "IMP.statistics", "impstatistics.html", null ],
    [ "IMP.symmetry", "impsymmetry.html", null ],
    [ "IMP.system", "impsystem.html", null ],
    [ "IMP.test", "imptest.html", null ],
    [ "IMP.EMageFit", "impEMageFit.html", null ],
    [ "IMP.cnmultifit_tools", "impcnmultifit_tools.html", null ],
    [ "IMP.em_tools", "impem_tools.html", null ],
    [ "IMP.example_app", "impexample_app.html", null ],
    [ "IMP.foxs", "impfoxs.html", null ],
    [ "IMP.integrative_docking", "impintegrative_docking.html", null ],
    [ "IMP.ligand_score", "impligand_score.html", null ],
    [ "IMP.multifit_tools", "impmultifit_tools.html", null ],
    [ "IMP.pdb_tools", "imppdb_tools.html", null ],
    [ "IMP.rmf_tools", "imprmf_tools.html", null ],
    [ "IMP.saxs_merge", "impsaxs_merge.html", null ],
    [ "IMP.saxs_tools", "impsaxs_tools.html", null ]
];

==> imp-doc-2.2.1.tar.gz: html/allmod.js <==
var allmod =
[
    [ "IMP.algebra", "impalgebra.html", [
      [ "Geometric primitives", "impalgebra.html#geometricprimitives", null ],
      [ "Generic geometry", "impalgebra.html#genericgeometry", null ],
      [ "ANN", "impalgebra.html#ANN", null ],
      [ "Eigen", "impalgebra.html#Eigen", null ]
    ] ],
    [ "IMP.atom", "impatom.html", null ],
    [ "IMP.base", "impbase.html", [
      [ "Graphs", "impbase.html#graphs", null ],
      [ "Values and Objects (C++ only)", "impbase.html#values", null ],
      [ "Google Perf Tools", "impbase.html#perf", null ]
    ] ],
    [ "IMP.benchmark", "impbenchmark.html", null ],
    [ "IMP.cgal", "impcgal.html", [
      [ "CGAL", "impcgal.html#CGAL", null ]
    ] ],
    [ "IMP.cnmultifit", "impcnmultifit.html", null ],
    [ "IMP.container", "impcontainer.html", null ],
    [ "IMP.core", "impcore.html", null ],
    [ "IMP.display", "impdisplay.html", null ],
    [ "IMP.domino", "impdomino.html", null ],
    [ "IMP.em", "impem.html", null ],
    [ "IMP.em2d", "impem2d.html", [
      [ "OpenCV", "impem2d.html#OpenCV", null ]
    ] ],
    [ "IMP.example", "impexample.html", null ],
    [ "IMP.gsl", "impgsl.html", [
      [ "GSL", "impgsl.html#GSL", null ]
    ] ],
    [ "IMP.isd", "impisd.html", null ],
    [ "IMP.kernel", "impkernel.html", null ],
    [ "IMP.kinematics", "impkinematics.html", null ],
    [ "IMP.kmeans", "impkmeans.html", null ],
    [ "IMP.misc", "impmisc.html", null ],
    [ "IMP.modeller", "impmodeller.html", [
      [ "Modeller", "impmodeller.html#modeller", null ]
    ] ],
    [ "IMP.module_template", "impmodule_template.html", null ],
    [ "IMP.mpi", "impmpi.html", null ],
    [ "IMP.multifit", "impmultifit.html", null ],
    [ "IMP.parallel", "impparallel.html", null ],
    [ "IMP.pepdock", "imppepdock.html", null ],
    [ "IMP.rmf", "imprmf.html", null ],
    [ "IMP.rotamer", "improtamer.html", null ],
    [ "IMP.saxs", "impsaxs.html", null ],
    [ "IMP.score_functor", "impscore_functor.html", null ],
    [ "IMP.scratch", "impscratch.html", null ],
    [ "IMP.statistics", "impstatistics.html", null ],
    [ "IMP.symmetry", "impsymmetry.html", null ],
    [ "IMP.test", "imptest.html", null ],
    [ "IMP.EMageFit", "impEMageFit.html", null ],
    [ "IMP.cnmultifit_tools", "impcnmultifit_tools.html", null ],
    [ "IMP.em_tools", "impem_tools.html", null ],
    [ "IMP.example_app", "impexample_app.html", null ],
    [ "IMP.foxs", "impfoxs.html", null ],
    [ "IMP.integrative_docking", "impintegrative_docking.html", null ],
    [ "IMP.ligand_score", "impligand_score.html", null ],
    [ "IMP.multifit_tools", "impmultifit_tools.html", null ],
    [ "IMP.pdb_tools", "imppdb_tools.html", null ],
    [ "IMP.rmf_tools", "imprmf_tools.html", null ],
    [ "IMP.saxs_merge", "impsaxs_merge.html", null ],
    [ "IMP.saxs_tools", "impsaxs_tools.html", null ]
];
